==> webkitgtk-2.6.5.tar.xz: webkitgtk-2.6.5/Source/cmakeconfig.h.cmake <==
#ifndef CMAKECONFIG_H
#define CMAKECONFIG_H

#cmakedefine01 ENABLE_3D_RENDERING
#cmakedefine01 ENABLE_ACCELERATED_2D_CANVAS
#cmakedefine01 ENABLE_ACCELERATED_OVERFLOW_SCROLLING
#cmakedefine01 ENABLE_API_TESTS
#cmakedefine01 ENABLE_AVF_CAPTIONS
#cmakedefine01 ENABLE_ASSEMBLER_WX_EXCLUSIVE
#cmakedefine01 ENABLE_BATTERY_STATUS
#cmakedefine01 ENABLE_CACHE_PARTITIONING
#cmakedefine01 ENABLE_CANVAS_PATH
#cmakedefine01 ENABLE_CANVAS_PROXY
#cmakedefine01 ENABLE_CHANNEL_MESSAGING
#cmakedefine01 ENABLE_CONTENT_FILTERING
#cmakedefine01 ENABLE_CONTEXT_MENUS
#cmakedefine01 ENABLE_CREDENTIAL_STORAGE
#cmakedefine01 ENABLE_CSP_NEXT
#cmakedefine01 ENABLE_CSS3_TEXT
#cmakedefine01 ENABLE_CSS3_TEXT_LINE_BREAK
#cmakedefine01 ENABLE_CSS_BOX_DECORATION_BREAK
#cmakedefine01 ENABLE_CSS_DEVICE_ADAPTATION
#cmakedefine01 ENABLE_CSS_COMPOSITING
#cmakedefine01 ENABLE_CSS_GRID_LAYOUT
#cmakedefine01 ENABLE_CSS_IMAGE_ORIENTATION
#cmakedefine01 ENABLE_CSS_IMAGE_RESOLUTION
#cmakedefine01 ENABLE_CSS_IMAGE_SET
#cmakedefine01 ENABLE_CSS_REGIONS
#cmakedefine01 ENABLE_CSS_SELECTORS_LEVEL4
#cmakedefine01 ENABLE_CSS_SHAPES
#cmakedefine01 ENABLE_CSS3_CONDITIONAL_RULES
#cmakedefine01 ENABLE_CURSOR_VISIBILITY
#cmakedefine01 ENABLE_CUSTOM_SCHEME_HANDLER
#cmakedefine01 ENABLE_DASHBOARD_SUPPORT
#cmakedefine01 ENABLE_DATACUE_VALUE
#cmakedefine01 ENABLE_DATALIST_ELEMENT
#cmakedefine01 ENABLE_DATA_TRANSFER_ITEMS
#cmakedefine01 ENABLE_DETAILS_ELEMENT
#cmakedefine01 ENABLE_DEVICE_ORIENTATION
#cmakedefine01 ENABLE_DOM4_EVENTS_CONSTRUCTOR
#cmakedefine01 ENABLE_DOWNLOAD_ATTRIBUTE
#cmakedefine01 ENABLE_DRAG_SUPPORT
#cmakedefine01 ENABLE_ENCRYPTED_MEDIA
#cmakedefine01 ENABLE_ENCRYPTED_MEDIA_V2
#cmakedefine01 ENABLE_EVENT_MODE_METATAGS
#cmakedefine01 ENABLE_FIXED_REPORTED_SIZE
#cmakedefine01 ENABLE_FTPDIR
#cmakedefine01 ENABLE_FTL_JIT
#cmakedefine01 ENABLE_FONT_LOAD_EVENTS
#cmakedefine01 ENABLE_FULLSCREEN_API
#cmakedefine01 ENABLE_GAMEPAD
#cmakedefine01 ENABLE_GAMEPAD_DEPRECATED
#cmakedefine01 ENABLE_GEOLOCATION
#cmakedefine01 ENABLE_HIDDEN_PAGE_DOM_TIMER_THROTTLING
#cmakedefine01 ENABLE_ICONDATABASE
#cmakedefine01 ENABLE_IMAGE_DECODER_DOWN_SAMPLING
#cmakedefine01 ENABLE_INDEXED_DATABASE
#cmakedefine01 ENABLE_INDEXED_DATABASE_IN_WORKERS
#cmakedefine01 ENABLE_INDIE_UI
#cmakedefine01 ENABLE_INPUT_TYPE_COLOR
#cmakedefine01 ENABLE_INPUT_TYPE_COLOR_POPOVER
#cmakedefine01 ENABLE_INPUT_TYPE_DATE
#cmakedefine01 ENABLE_INPUT_TYPE_DATETIME_INCOMPLETE
#cmakedefine01 ENABLE_INPUT_TYPE_DATETIMELOCAL
#cmakedefine01 ENABLE_INPUT_TYPE_TIME
#cmakedefine01 ENABLE_INPUT_TYPE_MONTH
#cmakedefine01 ENABLE_INPUT_TYPE_WEEK
#cmakedefine01 ENABLE_INSPECTOR
#cmakedefine01 ENABLE_IOS_AIRPLAY
#cmakedefine01 ENABLE_IOS_TEXT_AUTOSIZING
#cmakedefine01 ENABLE_JIT
#cmakedefine01 ENABLE_LEGACY_CSS_VENDOR_PREFIXES
#cmakedefine01 ENABLE_LEGACY_NOTIFICATIONS
#cmakedefine01 ENABLE_LEGACY_VENDOR_PREFIXES
#cmakedefine01 ENABLE_LEGACY_WEB_AUDIO
#cmakedefine01 ENABLE_LINK_PREFETCH
#cmakedefine01 ENABLE_LLINT_C_LOOP
#cmakedefine01 ENABLE_MATHML
#cmakedefine01 ENABLE_MEDIA_CAPTURE
#cmakedefine01 ENABLE_MEDIA_CONTROLS_SCRIPT
#cmakedefine01 ENABLE_MEDIA_SOURCE
#cmakedefine01 ENABLE_MEDIA_STATISTICS
#cmakedefine01 ENABLE_MEDIA_STREAM
#cmakedefine01 ENABLE_MEMORY_SAMPLER
#cmakedefine01 ENABLE_METER_ELEMENT
#cmakedefine01 ENABLE_MHTML
#cmakedefine01 ENABLE_MOUSE_CURSOR_SCALE
#cmakedefine01 ENABLE_NAVIGATOR_CONTENT_UTILS
#cmakedefine01 ENABLE_NAVIGATOR_HWCONCURRENCY
#cmakedefine01 ENABLE_NOSNIFF
#cmakedefine01 ENABLE_NETSCAPE_PLUGIN_API
#cmakedefine01 ENABLE_NETWORK_PROCESS
#cmakedefine01 ENABLE_NOTIFICATIONS
#cmakedefine01 ENABLE_ORIENTATION_EVENTS
#cmakedefine01 ENABLE_PDFKIT_PLUGIN
#cmakedefine01 ENABLE_PERFORMANCE_TIMELINE
#cmakedefine01 ENABLE_PICTURE_SIZES
#cmakedefine01 ENABLE_POINTER_LOCK
#cmakedefine01 ENABLE_PROMISES
#cmakedefine01 ENABLE_PROXIMITY_EVENTS
#cmakedefine01 ENABLE_PUBLIC_SUFFIX_LIST
#cmakedefine01 ENABLE_QUOTA
#cmakedefine01 ENABLE_REMOTE_INSPECTOR
#cmakedefine01 ENABLE_REQUEST_ANIMATION_FRAME
#cmakedefine01 ENABLE_RESOLUTION_MEDIA_QUERY
#cmakedefine01 ENABLE_RESOURCE_TIMING
#cmakedefine01 ENABLE_SECCOMP_FILTERS
#cmakedefine01 ENABLE_SERVICE_CONTROLS
#cmakedefine01 ENABLE_SATURATED_LAYOUT_ARITHMETIC
#cmakedefine01 ENABLE_SHARED_WORKERS
#cmakedefine01 ENABLE_SMOOTH_SCROLLING
#cmakedefine01 ENABLE_SPELLCHECK
#cmakedefine01 ENABLE_SQL_DATABASE
#cmakedefine01 ENABLE_SUBTLE_CRYPTO
#cmakedefine01 ENABLE_SVG_FONTS
#cmakedefine01 ENABLE_TELEPHONE_NUMBER_DETECTION
#cmakedefine01 ENABLE_TEMPLATE_ELEMENT
#cmakedefine01 ENABLE_TEXT_AUTOSIZING
#cmakedefine01 ENABLE_TOUCH_EVENTS
#cmakedefine01 ENABLE_TOUCH_SLIDER
#cmakedefine01 ENABLE_TOUCH_ICON_LOADING
#cmakedefine01 ENABLE_USERSELECT_ALL
#cmakedefine01 ENABLE_USER_TIMING
#cmakedefine01 ENABLE_VIBRATION
#cmakedefine01 ENABLE_VIDEO
#cmakedefine01 ENABLE_VIDEO_TRACK
#cmakedefine01 ENABLE_VIEWPORT_REFLOW
#cmakedefine01 ENABLE_VIEW_MODE_CSS_MEDIA
#cmakedefine01 ENABLE_WEBGL
#cmakedefine01 ENABLE_WEB_AUDIO
#cmakedefine01 ENABLE_WEBVTT_REGIONS
#cmakedefine01 ENABLE_WEB_REPLAY
#cmakedefine01 ENABLE_WEB_SOCKETS
#cmakedefine01 ENABLE_WEB_TIMING
#cmakedefine01 ENABLE_XHR_TIMEOUT
#cmakedefine01 ENABLE_XSLT
#cmakedefine01 USE_SYSTEM_MALLOC
#cmakedefine01 WTF_USE_GEOCLUE2
#cmakedefine01 WTF_USE_TILED_BACKING_STORE
#cmakedefine01 HAVE_LLVM
#cmakedefine01 HAVE_GTK_UNIX_PRINTING

#if defined(BUILDING_GTK__) && !defined(GTK_API_VERSION_2)
#define GDK_VERSION_MIN_REQUIRED @GDK_VERSION_MIN_REQUIRED@
#endif

#endif /* CMAKECONFIG_H */

==> webkitgtk-2.8.0.tar.xz: webkitgtk-2.8.0/Source/cmakeconfig.h.cmake <==
#ifndef CMAKECONFIG_H
#define CMAKECONFIG_H

#cmakedefine01 ENABLE_3D_RENDERING
#cmakedefine01 ENABLE_ACCELERATED_2D_CANVAS
#cmakedefine01 ENABLE_ACCELERATED_OVERFLOW_SCROLLING
#cmakedefine01 ENABLE_API_TESTS
#cmakedefine01 ENABLE_AVF_CAPTIONS
#cmakedefine01 ENABLE_ASSEMBLER_WX_EXCLUSIVE
#cmakedefine01 ENABLE_BATTERY_STATUS
#cmakedefine01 ENABLE_CACHE_PARTITIONING
#cmakedefine01 ENABLE_CANVAS_PATH
#cmakedefine01 ENABLE_CANVAS_PROXY
#cmakedefine01 ENABLE_CHANNEL_MESSAGING
#cmakedefine01 ENABLE_ES6_CLASS_SYNTAX
#cmakedefine01 ENABLE_CONTENT_FILTERING
#cmakedefine01 ENABLE_CONTEXT_MENUS
#cmakedefine01 ENABLE_CREDENTIAL_STORAGE
#cmakedefine01 ENABLE_CSP_NEXT
#cmakedefine01 ENABLE_CSS3_TEXT
#cmakedefine01 ENABLE_CSS3_TEXT_LINE_BREAK
#cmakedefine01 ENABLE_CSS_BOX_DECORATION_BREAK
#cmakedefine01 ENABLE_CSS_DEVICE_ADAPTATION
#cmakedefine01 ENABLE_CSS_COMPOSITING
#cmakedefine01 ENABLE_CSS_GRID_LAYOUT
#cmakedefine01 ENABLE_CSS_IMAGE_ORIENTATION
#cmakedefine01 ENABLE_CSS_IMAGE_RESOLUTION
#cmakedefine01 ENABLE_CSS_IMAGE_SET
#cmakedefine01 ENABLE_CSS_REGIONS
#cmakedefine01 ENABLE_CSS_SCROLL_SNAP
#cmakedefine01 ENABLE_CSS_SELECTORS_LEVEL4
#cmakedefine01 ENABLE_CSS_SHAPES
#cmakedefine01 ENABLE_CURSOR_VISIBILITY
#cmakedefine01 ENABLE_CUSTOM_SCHEME_HANDLER
#cmakedefine01 ENABLE_DASHBOARD_SUPPORT
#cmakedefine01 ENABLE_DATACUE_VALUE
#cmakedefine01 ENABLE_DATALIST_ELEMENT
#cmakedefine01 ENABLE_DATA_TRANSFER_ITEMS
#cmakedefine01 ENABLE_DETAILS_ELEMENT
#cmakedefine01 ENABLE_DEVICE_ORIENTATION
#cmakedefine01 ENABLE_DOM4_EVENTS_CONSTRUCTOR
#cmakedefine01 ENABLE_DOWNLOAD_ATTRIBUTE
#cmakedefine01 ENABLE_DRAG_SUPPORT
#cmakedefine01 ENABLE_ENCRYPTED_MEDIA
#cmakedefine01 ENABLE_ENCRYPTED_MEDIA_V2
#cmakedefine01 ENABLE_EVENT_MODE_METATAGS
#cmakedefine01 ENABLE_FILTERS_LEVEL_2
#cmakedefine01 ENABLE_FIXED_REPORTED_SIZE
#cmakedefine01 ENABLE_FTPDIR
#cmakedefine01 ENABLE_FTL_JIT
#cmakedefine01 ENABLE_FTL_NATIVE_CALL_INLINING
#cmakedefine01 ENABLE_FONT_LOAD_EVENTS
#cmakedefine01 ENABLE_FULLSCREEN_API
#cmakedefine01 ENABLE_GAMEPAD
#cmakedefine01 ENABLE_GAMEPAD_DEPRECATED
#cmakedefine01 ENABLE_GEOLOCATION
#cmakedefine01 ENABLE_HIDDEN_PAGE_DOM_TIMER_THROTTLING
#cmakedefine01 ENABLE_ICONDATABASE
#cmakedefine01 ENABLE_IMAGE_DECODER_DOWN_SAMPLING
#cmakedefine01 ENABLE_INDEXED_DATABASE
#cmakedefine01 ENABLE_INDEXED_DATABASE_IN_WORKERS
#cmakedefine01 ENABLE_INDIE_UI
#cmakedefine01 ENABLE_INPUT_TYPE_COLOR
#cmakedefine01 ENABLE_INPUT_TYPE_COLOR_POPOVER
#cmakedefine01 ENABLE_INPUT_TYPE_DATE
#cmakedefine01 ENABLE_INPUT_TYPE_DATETIME_INCOMPLETE
#cmakedefine01 ENABLE_INPUT_TYPE_DATETIMELOCAL
#cmakedefine01 ENABLE_INPUT_TYPE_TIME
#cmakedefine01 ENABLE_INPUT_TYPE_MONTH
#cmakedefine01 ENABLE_INPUT_TYPE_WEEK
#cmakedefine01 ENABLE_IOS_AIRPLAY
#cmakedefine01 ENABLE_IOS_TEXT_AUTOSIZING
#cmakedefine01 ENABLE_JIT
#cmakedefine01 ENABLE_LEGACY_CSS_VENDOR_PREFIXES
#cmakedefine01 ENABLE_LEGACY_NOTIFICATIONS
#cmakedefine01 ENABLE_LEGACY_VENDOR_PREFIXES
#cmakedefine01 ENABLE_LEGACY_WEB_AUDIO
#cmakedefine01 ENABLE_LINK_PREFETCH
#cmakedefine01 ENABLE_LLINT_C_LOOP
#cmakedefine01 ENABLE_MATHML
#cmakedefine01 ENABLE_MEDIA_CAPTURE
#cmakedefine01 ENABLE_MEDIA_CONTROLS_SCRIPT
#cmakedefine01 ENABLE_MEDIA_SOURCE
#cmakedefine01 ENABLE_MEDIA_STATISTICS
#cmakedefine01 ENABLE_MEDIA_STREAM
#cmakedefine01 ENABLE_MEMORY_SAMPLER
#cmakedefine01 ENABLE_METER_ELEMENT
#cmakedefine01 ENABLE_MHTML
#cmakedefine01 ENABLE_MOUSE_CURSOR_SCALE
#cmakedefine01 ENABLE_NAVIGATOR_CONTENT_UTILS
#cmakedefine01 ENABLE_NAVIGATOR_HWCONCURRENCY
#cmakedefine01 ENABLE_NOSNIFF
#cmakedefine01 ENABLE_NETSCAPE_PLUGIN_API
#cmakedefine01 ENABLE_NETWORK_PROCESS
#cmakedefine01 ENABLE_NOTIFICATIONS
#cmakedefine01 ENABLE_ORIENTATION_EVENTS
#cmakedefine01 ENABLE_PDFKIT_PLUGIN
#cmakedefine01 ENABLE_PERFORMANCE_TIMELINE
#cmakedefine01 ENABLE_PICTURE_SIZES
#cmakedefine01 ENABLE_POINTER_LOCK
#cmakedefine01 ENABLE_PROMISES
#cmakedefine01 ENABLE_PROXIMITY_EVENTS
#cmakedefine01 ENABLE_PUBLIC_SUFFIX_LIST
#cmakedefine01 ENABLE_QUOTA
#cmakedefine01 ENABLE_REMOTE_INSPECTOR
#cmakedefine01 ENABLE_REQUEST_ANIMATION_FRAME
#cmakedefine01 ENABLE_RESOLUTION_MEDIA_QUERY
#cmakedefine01 ENABLE_RESOURCE_TIMING
#cmakedefine01 ENABLE_SECCOMP_FILTERS
#cmakedefine01 ENABLE_SERVICE_CONTROLS
#cmakedefine01 ENABLE_SATURATED_LAYOUT_ARITHMETIC
#cmakedefine01 ENABLE_SMOOTH_SCROLLING
#cmakedefine01 ENABLE_SPELLCHECK
#cmakedefine01 ENABLE_STREAMS_API
#cmakedefine01 ENABLE_SUBTLE_CRYPTO
#cmakedefine01 ENABLE_SVG_FONTS
#cmakedefine01 ENABLE_TELEPHONE_NUMBER_DETECTION
#cmakedefine01 ENABLE_TEMPLATE_ELEMENT
#cmakedefine01 ENABLE_TEXT_AUTOSIZING
#cmakedefine01 ENABLE_TOUCH_EVENTS
#cmakedefine01 ENABLE_TOUCH_SLIDER
#cmakedefine01 ENABLE_TOUCH_ICON_LOADING
#cmakedefine01 ENABLE_USERSELECT_ALL
#cmakedefine01 ENABLE_USER_MESSAGE_HANDLERS
#cmakedefine01 ENABLE_USER_TIMING
#cmakedefine01 ENABLE_VIBRATION
#cmakedefine01 ENABLE_VIDEO
#cmakedefine01 ENABLE_VIDEO_TRACK
#cmakedefine01 ENABLE_VIEWPORT_REFLOW
#cmakedefine01 ENABLE_VIEW_MODE_CSS_MEDIA
#cmakedefine01 ENABLE_WEBGL
#cmakedefine01 ENABLE_WEB_AUDIO
#cmakedefine01 ENABLE_WEBVTT_REGIONS
#cmakedefine01 ENABLE_WEB_REPLAY
#cmakedefine01 ENABLE_WEB_SOCKETS
#cmakedefine01 ENABLE_WEB_TIMING
#cmakedefine01 ENABLE_XHR_TIMEOUT
#cmakedefine01 ENABLE_XSLT
#cmakedefine01 USE_SYSTEM_MALLOC
#cmakedefine01 WTF_USE_GEOCLUE2
#cmakedefine01 HAVE_LLVM
#cmakedefine01 HAVE_GTK_UNIX_PRINTING
#cmakedefine01 WTF_CPU_ARM64_CORTEXA53

#if defined(BUILDING_GTK__) && !defined(GTK_API_VERSION_2)
#define GDK_VERSION_MIN_REQUIRED @GDK_VERSION_MIN_REQUIRED@
#endif

#endif /* CMAKECONFIG_H */
